@@ -68,6 +68,11 @@ GLOBAL_ELEMENT(ACR_Performing_physician  , 0x0008, 0x1050, PN);
 GLOBAL_ELEMENT(ACR_Operators_name        , 0x0008, 0x1070, PN);
 GLOBAL_ELEMENT(ACR_Manufacturer_model    , 0x0008, 0x1090, LO);
 
+/* See C.8.12.3.1.6 for full list of possible values, but for DTI
+ * images this field _should_ equal "DIFFUSION"
+ */
+GLOBAL_ELEMENT(ACR_Acquisition_contrast  , 0x0008, 0x9209, CS);
+
 GLOBAL_ELEMENT(ACR_Patient_name          , 0x0010, 0x0010, PN);
 GLOBAL_ELEMENT(ACR_Patient_identification, 0x0010, 0x0020, LO);
 GLOBAL_ELEMENT(ACR_Patient_birth_date    , 0x0010, 0x0030, DA);
@@ -97,6 +102,7 @@ GLOBAL_ELEMENT(ACR_Device_serial_number  , 0x0018, 0x1000, LO);
 GLOBAL_ELEMENT(ACR_Software_versions     , 0x0018, 0x1020, LO);
 GLOBAL_ELEMENT(ACR_Protocol_name         , 0x0018, 0x1030, LO);
 GLOBAL_ELEMENT(ACR_Calibration_date      , 0x0018, 0x1200, DA);
+GLOBAL_ELEMENT(ACR_Calibration_time      , 0x0018, 0x1201, TM); /*added ilana*/
 GLOBAL_ELEMENT(ACR_Actual_frame_duration , 0x0018, 0x1242, IS);
 GLOBAL_ELEMENT(ACR_Receive_coil_name     , 0x0018, 0x1250, SH);
 GLOBAL_ELEMENT(ACR_Transmit_coil_name    , 0x0018, 0x1251, SH);
@@ -106,6 +112,13 @@ GLOBAL_ELEMENT(ACR_Flip_angle            , 0x0018, 0x1314, DS);
 GLOBAL_ELEMENT(ACR_SAR                   , 0x0018, 0x1316, DS);
 GLOBAL_ELEMENT(ACR_Acq_comments          , 0x0018, 0x4000, LT);
 GLOBAL_ELEMENT(ACR_Patient_position      , 0x0018, 0x5100, CS);
+/* Supplement 49 stuff, section C.8.12.5.9 pp 94-95. */
+GLOBAL_ELEMENT(ACR_Diffusion_directionality, 0x0018, 0x9075, CS);
+GLOBAL_ELEMENT(ACR_Diffusion_gradient_direction_seq, 0x0018, 0x9076, SQ);
+GLOBAL_ELEMENT(ACR_Diffusion_b_value     , 0x0018, 0x9087, FD);
+GLOBAL_ELEMENT(ACR_Diffusion_gradient_orientation, 0x0018, 0x9089, FD);
+GLOBAL_ELEMENT(ACR_MR_Diffusion_seq      , 0x0018, 0x9117, SQ);
+GLOBAL_ELEMENT(ACR_Diffusion_anisotropy_type, 0x0018, 0x9147, CS);
 
 GLOBAL_ELEMENT(ACR_Series_instance_UID   , 0x0020, 0x000E, UI);
 GLOBAL_ELEMENT(ACR_Study                 , 0x0020, 0x0010, SH);
@@ -123,6 +136,7 @@ GLOBAL_ELEMENT(ACR_Number_of_temporal_positions,
 GLOBAL_ELEMENT(ACR_Acquisitions_in_series, 0x0020, 0x1001, IS);
 GLOBAL_ELEMENT(ACR_Images_in_acquisition,  0x0020, 0x1002, IS);
 GLOBAL_ELEMENT(ACR_Slice_location,         0x0020, 0x1041, DS);
+GLOBAL_ELEMENT(ACR_Image_comments,         0x0020, 0x4000, DS);
 
 GLOBAL_ELEMENT(ACR_Number_of_frames      , 0x0028, 0x0008, IS);
 GLOBAL_ELEMENT(ACR_Frame_increment_ptr   , 0x0028, 0x0009, AT);
@@ -141,6 +155,7 @@ GLOBAL_ELEMENT(ACR_Window_width          , 0x0028, 0x1051, DS);
 GLOBAL_ELEMENT(ACR_Rescale_intercept     , 0x0028, 0x1052, DS);
 GLOBAL_ELEMENT(ACR_Rescale_slope         , 0x0028, 0x1053, DS);
 
+GLOBAL_ELEMENT(ACR_Detector_information_seq, 0x0054, 0x0022, SQ);
 GLOBAL_ELEMENT(ACR_Number_of_slices      , 0x0054, 0x0081, US);
 GLOBAL_ELEMENT(ACR_Number_of_time_slices , 0x0054, 0x0101, US);
 GLOBAL_ELEMENT(ACR_Units                 , 0x0054, 0x1001, CS);
