@@ -5,6 +5,18 @@
 @CREATED    : June 2001 (Rick Hoge)
 @MODIFIED   : 
  * $Log: dcm2mnc.c,v $
+ * Revision 1.20  2007/05/30 15:17:34  ilana
+ * fix so that diffusion images all written into 1 4d volume, gradient directions and bvalues are written to mincheader, some fixes for TIM diffusion images
+ *
+ * Revision 1.19  2005/11/11 18:42:54  bert
+ * Latest fixes to dcm2mnc
+ *
+ * Revision 1.18  2005/11/04 22:25:04  bert
+ * Update version string to 2.0.07
+ *
+ * Revision 1.17  2005/08/26 21:25:54  bert
+ * Latest changes ported from 1.0 branch
+ *
  * Revision 1.14.2.10  2005/08/18 18:17:36  bert
  * Add -usecoordinates option
  *
@@ -116,7 +128,7 @@
  *
 ---------------------------------------------------------------------------- */
 
-static const char rcsid[]="$Header: /private-cvsroot/minc/conversion/dcm2mnc/dcm2mnc.c,v 1.14.2.10 2005/08/18 18:17:36 bert Exp $";
+static const char rcsid[]="$Header: /private-cvsroot/minc/conversion/dcm2mnc/dcm2mnc.c,v 1.20 2007/05/30 15:17:34 ilana Exp $";
 
 #define GLOBAL_ELEMENT_DEFINITION /* To define elements */
 #include "dcm2mnc.h"
@@ -141,7 +153,7 @@ static int check_file_type_consistency(int num_files, const char *file_list[]);
 
 struct globals G;
 
-#define VERSION_STRING "2.0.06 built " __DATE__ " " __TIME__
+#define VERSION_STRING "2.0.07 built " __DATE__ " " __TIME__
 
 #ifndef S_ISDIR
 #define S_ISDIR(x) (((x) & _S_IFMT) == _S_IFDIR)
@@ -835,7 +847,7 @@ use_the_files(int num_files,
                                     G.clobber, 
                                     file_prefix, 
                                     &output_file_name);
-
+				    
         G.opts = user_opts;
        
         if (exit_status != EXIT_SUCCESS) 
@@ -921,7 +933,7 @@ is_ima_file(const char *fullname)
         /* We only deal with Siemens IMA files - not sure any other kinds 
          * exist, frankly.
          */
-        if (!strcmp(mfg_str, IMA_MAGIC_STR)) {
+        if (!memcmp(mfg_str, IMA_MAGIC_STR, IMA_MAGIC_SIZE)) {
             result = 1;
         }
         fclose(fp);
