@@ -7,6 +7,27 @@
    @CREATED    : January 28, 1997 (Peter Neelin)
    @MODIFIED   : 
    * $Log: dicom_read.c,v $
+   * Revision 1.24  2007/06/08 20:28:57  ilana
+   * added several fields to mincheader (dicom elements and found in ASCONV header)
+   *
+   * Revision 1.23  2007/05/30 15:17:34  ilana
+   * fix so that diffusion images all written into 1 4d volume, gradient directions and bvalues are written to mincheader, some fixes for TIM diffusion images
+   *
+   * Revision 1.22  2006/04/09 15:38:02  bert
+   * Add support for standard DTI fields
+   *
+   * Revision 1.21  2005/12/05 16:50:08  bert
+   * Deal with weird XMedCon images
+   *
+   * Revision 1.20  2005/10/26 23:43:35  bert
+   * Latest attempt at getting slice spacing consistent
+   *
+   * Revision 1.19  2005/09/16 22:13:33  bert
+   * Fix slice spacing handling
+   *
+   * Revision 1.18  2005/08/26 21:25:54  bert
+   * Latest changes ported from 1.0 branch
+   *
    * Revision 1.16.2.5  2005/08/26 03:50:16  bert
    * Use ACR_Number_of_temporal_positions for number of time slices
    *
@@ -504,14 +525,21 @@ get_file_info(Acr_Group group_list, File_Info *fi_ptr, General_Info *gi_ptr)
     double steps[VOL_NDIMS];    /* Step (spacing) coordinates */
     double starts[VOL_NDIMS];   /* Start (origin) coordinates */
     Acr_Element_Id mri_index_list[MRI_NDIMS];
+    Acr_Element_Id mri_total_list[MRI_NDIMS]; /*added by ilana*/
+    Acr_Element element;
 
-    // Initialize array of elements for MRI positions (indices)
-    //
-    mri_index_list[SLICE] = SPI_Current_slice_number;
-    mri_index_list[ECHO] = ACR_Echo_number;
-    mri_index_list[TIME] = ACR_Acquisition;
-    mri_index_list[PHASE] = NULL;
-    mri_index_list[CHEM_SHIFT] = NULL;
+   // Array of elements for mri dimensions
+   mri_index_list[SLICE] = SPI_Current_slice_number;
+   mri_index_list[ECHO] = ACR_Echo_number;
+   // dicom time element may be different on old systems
+   mri_index_list[TIME] = ACR_Acquisition;
+   mri_index_list[PHASE] = NULL;
+   mri_index_list[CHEM_SHIFT] = NULL;
+   mri_total_list[SLICE] = SPI_Number_of_slices_nominal;
+   mri_total_list[ECHO] = SPI_Number_of_echoes;
+   mri_total_list[TIME] = ACR_Acquisitions_in_series;
+   mri_total_list[PHASE] = NULL;
+   mri_total_list[CHEM_SHIFT] = NULL;
 
     /* Get image dimensions
      */
@@ -546,15 +574,18 @@ get_file_info(Acr_Group group_list, File_Info *fi_ptr, General_Info *gi_ptr)
 
     /* Get indices for image in current file
      */
-    for (imri = 0; imri < MRI_NDIMS; imri++) {
-        if (mri_index_list[imri] != NULL) {
-            fi_ptr->index[imri] = acr_find_int(group_list,
-                                               mri_index_list[imri], 1);
-        }
-        else {
-            fi_ptr->index[imri] = 1;
-        }
-    }
+   for (imri=0; imri < MRI_NDIMS; imri++) {
+     
+     if (mri_index_list[imri] != NULL) {
+       fi_ptr->index[imri] = 
+	 /* note that for TIME this will use ACR_Acqusition,
+	    which does not work for measurement loop scans */
+	 acr_find_int(group_list, mri_index_list[imri], 1);
+     }
+     else {
+       fi_ptr->index[imri] = 1;
+     }
+   }
 
     /* Get coordinate information
      */
@@ -572,10 +603,14 @@ get_file_info(Acr_Group group_list, File_Info *fi_ptr, General_Info *gi_ptr)
      * index.  IMA files do not seem to have a reliable slice time
      * indicator.
      */
-    if (G.file_type != IMA) {
+    /*if (G.file_type != IMA) {
         fi_ptr->index[TIME] = irnd(fi_ptr->coordinate[TIME] * 100.0);
-    }
+    }*/
 
+    //ilana debug
+    //int test = fi_ptr->coordinate[TIME];
+    //print ("*******Time coordinate IS: %i\n\n",test);
+    
     /* Set up general info on first pass
      */
     if (!gi_ptr->initialized) {
@@ -602,6 +637,17 @@ get_file_info(Acr_Group group_list, File_Info *fi_ptr, General_Info *gi_ptr)
         if ((gi_ptr->pixel_max != fi_ptr->pixel_max) ||
             (gi_ptr->pixel_min != fi_ptr->pixel_min)) {
             printf("WARNING: Inconsistent pixel minimum and maximum\n");
+            printf("    %f %f, %f %f\n",
+                   gi_ptr->pixel_min, gi_ptr->pixel_max,
+                   fi_ptr->pixel_min, fi_ptr->pixel_max);
+#if 0
+            if (gi_ptr->pixel_max < fi_ptr->pixel_max) {
+                gi_ptr->pixel_max = fi_ptr->pixel_max;
+            }
+            if (gi_ptr->pixel_min > fi_ptr->pixel_min) {
+                gi_ptr->pixel_min = fi_ptr->pixel_min;
+            }
+#endif
         }
      
         /* Check for consistent data type */
@@ -642,6 +688,9 @@ get_file_info(Acr_Group group_list, File_Info *fi_ptr, General_Info *gi_ptr)
             /* Get current index */
             cur_index = fi_ptr->index[imri];
        
+	    //ilana debug
+	    //print ("************CURRENT INDEX IS: %i\n\n",cur_index);
+	    
             /* Check whether this index is in the list.
              */
             if (gi_ptr->cur_size[imri] == 1) {
@@ -703,6 +752,21 @@ get_file_info(Acr_Group group_list, File_Info *fi_ptr, General_Info *gi_ptr)
      
     }  // Update general info for this file
 
+    /* Get DTI information if available. 
+     */
+    fi_ptr->b_value = acr_find_double(group_list, ACR_Diffusion_b_value, -1);
+
+    element = acr_find_group_element(group_list, 
+                                     ACR_Diffusion_gradient_orientation);
+    
+    if (element == NULL ||
+        acr_get_element_double_array(element, WORLD_NDIMS,
+                                     fi_ptr->grad_direction) != WORLD_NDIMS) {
+        fi_ptr->grad_direction[XCOORD] = 
+            fi_ptr->grad_direction[YCOORD] = 
+            fi_ptr->grad_direction[ZCOORD] = 0; /*this should be 0 for the b=0 images  ilana*/
+    }
+    
     // If we get to here, then we have a valid file
     fi_ptr->valid = TRUE;
     return;
@@ -994,8 +1058,16 @@ dicom_read_position(Acr_Group group_list, int n, double coordinate[3])
     else {
         result = DICOM_POSITION_GLOBAL; /* Found a global position */
 
-        element = acr_find_group_element(group_list, 
-                                         ACR_Image_position_patient);
+        /* bert-look for field in weird XMedCon location
+         */
+        element = acr_recurse_for_element(group_list, 0,
+                                          ACR_Detector_information_seq,
+                                          ACR_Image_position_patient);
+
+        if (element == NULL) {
+            element = acr_find_group_element(group_list, 
+                                             ACR_Image_position_patient);
+        }
 
         if (element == NULL) {
             element = acr_find_group_element(group_list, 
@@ -1034,6 +1106,15 @@ dicom_read_orientation(Acr_Group group_list, double orientation[6])
     element = acr_recurse_for_element(group_list, 0, 
                                       ACR_Shared_func_groups_seq,
                                       ACR_Image_orientation_patient);
+
+    /* bert - deal with weird XMedCon images...
+     */
+    if (element == NULL) {
+        element = acr_recurse_for_element(group_list, 0,
+                                          ACR_Detector_information_seq,
+                                          ACR_Image_orientation_patient);
+    }
+
     if (element == NULL) {
         element = acr_find_group_element(group_list, 
                                          ACR_Image_orientation_patient);
@@ -1147,7 +1228,7 @@ get_coordinate_info(Acr_Group group_list,
     double magnitude;
     double largest;
     double psize[IMAGE_NDIMS];
-    double dbl_tmp1, dbl_tmp2;
+    double slice_thickness, slice_spacing;
     int result;
 
     double RowColVec[6]; /* row/column unit vectors in public dicom element */
@@ -1338,12 +1419,18 @@ get_coordinate_info(Acr_Group group_list,
 
     /* Figure out the slice thickness.  It could be from either one of
      * two possible places in the file.
+     * 
+     * This code has changed several times, and there may be no single
+     * correct way of deriving the true slice spacing from the official
+     * DICOM slice thickness and slice spacing fields.  My best guess is
+     * to look for both fields, and to adopt the 
      */
-    dbl_tmp1 = acr_find_double(group_list, ACR_Slice_thickness, 0.0);
-    dbl_tmp2 = acr_find_double(group_list, ACR_Spacing_between_slices, 0.0);
+    slice_thickness = acr_find_double(group_list, ACR_Slice_thickness, 0);
+    slice_spacing = acr_find_double(group_list, ACR_Spacing_between_slices, 0);
 
-    if (dbl_tmp1 == 0.0) {
-        if (dbl_tmp2 == 0.0) {
+    if (slice_thickness == 0.0) {
+        /* No slice thickness value found. */
+        if (slice_spacing == 0.0) {
             if (G.Debug >= HI_LOGGING) {
                 printf("Using default slice thickness of 1.0\n");
             }
@@ -1353,23 +1440,28 @@ get_coordinate_info(Acr_Group group_list,
             if (G.Debug >= HI_LOGGING) {
                 printf("Using (0018,0088) for slice thickness\n");
             }
-            steps[VSLICE] = dbl_tmp2;
+            steps[VSLICE] = slice_spacing;
         }
     }
-    else if (dbl_tmp2 == 0.0) {
+    else if (slice_spacing == 0.0) {
+        /* No slice spacing value found. */
         if (G.Debug >= HI_LOGGING) {
             printf("Using (0018,0050) for slice thickness\n");
         }
-        steps[VSLICE] = dbl_tmp1;
+        steps[VSLICE] = slice_thickness;
     }
     else {
-        if (G.Debug && !NEARLY_EQUAL(dbl_tmp1, dbl_tmp2)) {
+        /* Both fields are set.  I choose the slice spacing rather
+         * than the slice thickness in this case. However, I believe
+         * there is some evidence that this can cause problems in rare
+         * cases.
+         */
+        if (G.Debug && !NEARLY_EQUAL(slice_thickness, slice_spacing)) {
             printf("WARNING: slice thickness conflict: ");
-            printf("old = %.10f, new = %.10f\n", dbl_tmp1, dbl_tmp2);
+            printf("old = %.10f, new = %.10f\n", 
+                   slice_thickness, slice_spacing);
         }
-        /* Use the minimum slice spacing. */
-        steps[VSLICE] = (dbl_tmp2 < dbl_tmp1) ? dbl_tmp2 : dbl_tmp1;
-        /* steps[VSLICE] = dbl_tmp2; */
+        steps[VSLICE] = slice_spacing;
     }
 
     /* Make sure that direction cosines point the right way (dot
@@ -1612,8 +1704,15 @@ get_general_header_info(Acr_Group group_list, General_Info *gi_ptr)
 
     get_string_field(gi_ptr->patient.reg_time, 
                      group_list, ACR_Study_time);
-
+    
+    get_string_field(gi_ptr->patient.position, /*position of patient added by ilana*/
+                     group_list, ACR_Patient_position);
+    
     /* Get study info */
+    
+    /*some more timing info added by ilana*/
+    get_string_field(gi_ptr->acq.series_time, group_list, ACR_Series_time);
+        
     get_string_field(gi_ptr->study.start_time, 
                      group_list, ACR_Study_date);
 
@@ -1639,6 +1738,8 @@ get_general_header_info(Acr_Group group_list, General_Info *gi_ptr)
                      group_list, ACR_Device_serial_number);
     get_string_field(gi_ptr->study.calibration_date, 
                      group_list, ACR_Calibration_date);
+    get_string_field(gi_ptr->study.calibration_time, /*add time as well ilana*/
+                     group_list, ACR_Calibration_time);
     get_string_field(gi_ptr->study.institution, 
                      group_list, ACR_Institution_id);
     get_string_field(gi_ptr->study.station_id, 
@@ -1659,14 +1760,31 @@ get_general_header_info(Acr_Group group_list, General_Info *gi_ptr)
          acr_find_int(group_list, ACR_Series, 0), gi_ptr->acq_id); */
     sprintf(gi_ptr->study.acquisition_id, "%d", gi_ptr->acq_id);
 
-    /* Get acquisition information */
 
+    
+    /* Get acquisition information */
+    
+    get_string_field(gi_ptr->acq.acquisition_time, group_list, ACR_Acquisition_time); /*add acquisition start time ilana*/
+    get_string_field(gi_ptr->acq.image_time, group_list, ACR_Image_time);
     get_string_field(gi_ptr->acq.scan_seq, group_list, ACR_Sequence_name);
     get_string_field(gi_ptr->acq.protocol_name, group_list, ACR_Protocol_name);
+    get_string_field(gi_ptr->acq.series_description,         /*add series description ilana*/
+                     group_list, ACR_Series_description);
     get_string_field(gi_ptr->acq.receive_coil, group_list, 
                      ACR_Receive_coil_name);
     get_string_field(gi_ptr->acq.transmit_coil, group_list, 
                      ACR_Transmit_coil_name);
+    get_string_field(gi_ptr->acq.slice_order, group_list,
+		     EXT_Slice_order);
+      /*0x1 means ASCENDING
+	0x2 means DESCENDING
+	0x4 means INTERLEAVED*/
+    if(!strcmp(gi_ptr->acq.slice_order,"0x1 "))
+	strncpy(gi_ptr->acq.slice_order, "ascending", STRING_T_LEN);
+    else if(!strcmp(gi_ptr->acq.slice_order,"0x2 "))
+	strncpy(gi_ptr->acq.slice_order, "descending", STRING_T_LEN);
+    else if(!strcmp(gi_ptr->acq.slice_order,"0x4 "))
+	strncpy(gi_ptr->acq.slice_order, "interleaved", STRING_T_LEN);
 
     gi_ptr->acq.rep_time = 
         acr_find_double(group_list, ACR_Repetition_time, -DBL_MAX);
@@ -1678,6 +1796,9 @@ get_general_header_info(Acr_Group group_list, General_Info *gi_ptr)
     if (gi_ptr->acq.echo_time != -DBL_MAX)
         gi_ptr->acq.echo_time /= 1000.0;
 
+    gi_ptr->acq.echo_time = 
+        acr_find_double(group_list, ACR_Echo_train_length, -DBL_MAX); /*added echo train length ilana*/
+    
     gi_ptr->acq.echo_number = 
         acr_find_double(group_list, ACR_Echo_number, -DBL_MAX);
 
@@ -1685,6 +1806,10 @@ get_general_header_info(Acr_Group group_list, General_Info *gi_ptr)
         acr_find_double(group_list, ACR_Inversion_time, -DBL_MAX);
     if (gi_ptr->acq.inv_time != -DBL_MAX)
         gi_ptr->acq.inv_time /= 1000.0;
+    gi_ptr->acq.delay_in_TR = 
+        acr_find_double(group_list, EXT_Delay_in_TR, -DBL_MAX);  /*added delay in TR ilana*/
+    if (gi_ptr->acq.delay_in_TR != -DBL_MAX)
+        gi_ptr->acq.delay_in_TR /= 1000000.0; /*write in seconds*/ 
     gi_ptr->acq.b_value = 
         acr_find_double(group_list, EXT_Diffusion_b_value, -DBL_MAX);
     gi_ptr->acq.flip_angle = 
@@ -1710,11 +1835,11 @@ get_general_header_info(Acr_Group group_list, General_Info *gi_ptr)
 
     gi_ptr->acq.num_phase_enc_steps = 
         acr_find_double(group_list, ACR_Number_of_phase_encoding_steps, -DBL_MAX);
-    gi_ptr->acq.percent_sampling = 100 * 
-        acr_find_double(group_list, ACR_Percent_sampling, -DBL_MAX);
+    gi_ptr->acq.percent_sampling = 
+		    acr_find_double(group_list, ACR_Percent_sampling, -DBL_MAX); /*don't need to multiply by 100 ilana*/
 
-    gi_ptr->acq.percent_phase_fov = 100 *
-        acr_find_double(group_list, ACR_Percent_phase_field_of_view, -DBL_MAX);
+    gi_ptr->acq.percent_phase_fov = 
+		    acr_find_double(group_list, ACR_Percent_phase_field_of_view, -DBL_MAX); /*don't need to multiply by 100 ilana*/
 
     gi_ptr->acq.pixel_bandwidth = 
         acr_find_double(group_list, ACR_Pixel_bandwidth, -DBL_MAX);
@@ -1734,8 +1859,11 @@ get_general_header_info(Acr_Group group_list, General_Info *gi_ptr)
     get_string_field(gi_ptr->acq.phase_enc_dir, 
                      group_list, ACR_Phase_encoding_direction);
 
-    strncpy(gi_ptr->acq.comments, "", STRING_T_LEN);
-
+    /*Add image comments ilana*/
+    /*strncpy(gi_ptr->acq.comments, "", STRING_T_LEN);*/
+    get_string_field(gi_ptr->acq.comments, 
+                     group_list, ACR_Image_comments);
+    
     /* Siemens Numaris 4 specific!
      */
 
@@ -1745,6 +1873,9 @@ get_general_header_info(Acr_Group group_list, General_Info *gi_ptr)
 #else
     gi_ptr->acq.MrProt = strdup("");
 #endif
+
+    string = acr_find_string(group_list, ACR_Acquisition_contrast, "");
+    gi_ptr->acq.dti = (strstr(string, "DIFFUSION") != NULL);
 }
 
 /* ----------------------------- MNI Header -----------------------------------
