@@ -7,6 +7,18 @@
    @CREATED    : January 28, 1997 (Peter Neelin)
    @MODIFIED   : 
    * $Log: minc_file.c,v $
+   * Revision 1.13  2007/06/08 20:28:57  ilana
+   * added several fields to mincheader (dicom elements and found in ASCONV header)
+   *
+   * Revision 1.12  2006/04/09 15:34:32  bert
+   * Add ability to save DTI parameters using Jennifer Campbell's convention
+   *
+   * Revision 1.11  2005/11/04 22:26:16  bert
+   * Combined cloned code into a single check_regular() function
+   *
+   * Revision 1.10  2005/08/26 21:25:54  bert
+   * Latest changes ported from 1.0 branch
+   *
    * Revision 1.6.2.7  2005/08/18 18:17:55  bert
    * Fix up one warning message
    *
@@ -122,7 +134,7 @@
    software for any purpose.  It is provided "as is" without
    express or implied warranty.
 ---------------------------------------------------------------------------- */
-static const char rcsid[] = "$Header: /private-cvsroot/minc/conversion/dcm2mnc/minc_file.c,v 1.6.2.7 2005/08/18 18:17:55 bert Exp $";
+static const char rcsid[] = "$Header: /private-cvsroot/minc/conversion/dcm2mnc/minc_file.c,v 1.13 2007/06/08 20:28:57 ilana Exp $";
 
 #include "dcm2mnc.h"
 
@@ -132,6 +144,38 @@ static const char rcsid[] = "$Header: /private-cvsroot/minc/conversion/dcm2mnc/m
 static char *mri_dim_names[] = {
     NULL, "echo_time", MItime, "phase_number", "chemical_shift", NULL};
 
+/*
+ * verify that a list of coordinates is "regular", that is, that the
+ * spacing between each adjacent pair does not vary by more than a
+ * small amount relative to an average stepsize.
+ */
+int
+check_regular(double step, double coordinates[], int length)
+{
+    int index;
+    double diff;
+
+    if (step == 0.0) {
+        step = 1.0;             /* avoid division by zero */
+    }
+
+    for (index = 1; index < length; index++) {
+        /* Calculate the difference between two adjacent locations,
+         * less the average step value.
+         */
+        diff = (coordinates[index] - coordinates[index - 1]) - step;
+        
+        if (diff < 0.0) {
+            diff = -diff;
+        }
+        diff /= step;
+        if (diff > COORDINATE_EPSILON) {
+            return FALSE;
+        }
+    }
+    return TRUE;
+}
+
 int 
 strfminc(char *str_ptr, int str_max, const char *fmt_ptr, 
          General_Info *gi_ptr)
@@ -430,7 +474,6 @@ minc_set_spacing(int mincid, int varid, Mri_Index imri, General_Info *gi_ptr)
 {
     double sum = 0.0;   /* Sum of differences for computing average */
     double avg;                 /* Average */
-    double diff;                /* Difference between adjacent coordinates */
     double step;                /* Step size from widths */
     int regular;                /* TRUE if dimension is regular */
     int index;                  /* Loop/array index */
@@ -472,26 +515,7 @@ minc_set_spacing(int mincid, int varid, Mri_Index imri, General_Info *gi_ptr)
 
         /* Check for uniformity of spacing */
 
-        for (index = 1; index < length; index++) {
-
-            /* Calculate the difference between two adjacent locations,
-             * less the average step value.
-             */
-
-            diff = gi_ptr->coordinates[imri][index] -
-                gi_ptr->coordinates[imri][index - 1] - step;
-        
-            if (diff < 0.0) {
-                diff = -diff;
-            }
-            if (step != 0.0) {
-                diff /= step;
-            }
-            if (diff > COORDINATE_EPSILON) {
-                regular = FALSE;
-                break;
-            }
-        }
+        regular = check_regular(step, gi_ptr->coordinates[imri], length);
     }
     else {
         /* We have widths provided for us, so use them to calculate the
@@ -563,7 +587,6 @@ void setup_minc_variables(int mincid, General_Info *general_info,
     char name[MAX_NC_NAME];
     int index;
     int regular;
-    double separation, diff;
     Acr_Group cur_group;
     Acr_Element cur_element;
     int length;
@@ -665,23 +688,15 @@ void setup_minc_variables(int mincid, General_Info *general_info,
             varid = micreate_std_variable(mincid, dimname, NC_DOUBLE, 
                                           1, &dim[ndims]);
             /* Check for regular slices */
-            regular = TRUE;
-            separation = general_info->step[general_info->slice_world];
-            for (index=1; index < general_info->cur_size[SLICE]; index++) {
-                diff = general_info->coordinates[SLICE][index] -
-                    general_info->coordinates[SLICE][index-1] - separation;
-                if (diff < 0.0) diff = -diff;
-                if (separation != 0.0) diff /= separation;
-                if (diff > COORDINATE_EPSILON) {
-                    regular = FALSE;
-                    break;
-                }
-            }
-            if (regular)
+            if (check_regular(general_info->step[general_info->slice_world],
+                              general_info->coordinates[SLICE],
+                              general_info->cur_size[SLICE])) {
                 miattputstr(mincid, varid, MIspacing, MI_REGULAR);
+            }
         }
-        else
+        else {
             varid = micreate_std_variable(mincid, dimname, NC_LONG, 0, NULL);
+        }
         miattputdbl(mincid, varid, MIstep, 
                     general_info->step[iworld]);
         miattputdbl(mincid, varid, MIstart, 
@@ -742,6 +757,9 @@ void setup_minc_variables(int mincid, General_Info *general_info,
     if (general_info->patient.weight != -DBL_MAX) 
         miattputdbl(mincid, varid, MIweight, 
                     general_info->patient.weight);
+    if (strlen(general_info->patient.position) > 0)
+        miattputstr(mincid, varid, "position", 
+                    general_info->patient.position);
 
     /* Create the study variable */
     varid = micreate_group_variable(mincid, MIstudy);
@@ -753,6 +771,8 @@ void setup_minc_variables(int mincid, General_Info *general_info,
     if (strlen(general_info->patient.reg_time) > 0)
         miattputstr(mincid, varid, MIstart_time, 
                     general_info->patient.reg_time);
+
+    
     if (strlen(general_info->study.modality) > 0)
         miattputstr(mincid, varid, MImodality, 
                     general_info->study.modality);
@@ -774,6 +794,9 @@ void setup_minc_variables(int mincid, General_Info *general_info,
     if (strlen(general_info->study.calibration_date) > 0)
         miattputstr(mincid, varid, "calibration_date", 
                     general_info->study.calibration_date);
+    if (strlen(general_info->study.calibration_time) > 0)
+        miattputstr(mincid, varid, "calibration_time", 
+                    general_info->study.calibration_time);
     if (strlen(general_info->study.institution) > 0)
         miattputstr(mincid, varid, MIinstitution, 
                     general_info->study.institution);
@@ -806,11 +829,23 @@ void setup_minc_variables(int mincid, General_Info *general_info,
     if (strlen(general_info->study.start_time) > 0)
         miattputstr(mincid, varid, MIstart_time, 
                     general_info->study.start_time);
-
+        /*added some more study info*/
+    if (strlen(general_info->acq.series_time) > 0)
+        miattputstr(mincid, varid, "series_time", 
+                    general_info->acq.series_time);
+    if (strlen(general_info->acq.acquisition_time) > 0) /*should use this instead of the Study time*/ 
+        miattputstr(mincid, varid, "acquisition_time",  
+                    general_info->acq.acquisition_time);
+    if (strlen(general_info->acq.image_time) > 0)
+        miattputstr(mincid, varid, "image_time", 
+                    general_info->acq.image_time);
+    
     if (strlen(general_info->acq.scan_seq) > 0)
         miattputstr(mincid, varid, MIscanning_sequence, 
                     general_info->acq.scan_seq);
-
+    if (strlen(general_info->acq.series_description) > 0) /*add Series Description*/
+        miattputstr(mincid, varid, "series_description", 
+                    general_info->acq.series_description);
     if (strlen(general_info->acq.protocol_name) > 0)
         miattputstr(mincid, varid, MIprotocol, 
                     general_info->acq.protocol_name);
@@ -831,6 +866,9 @@ void setup_minc_variables(int mincid, General_Info *general_info,
     if (general_info->acq.echo_number != -DBL_MAX)
         miattputdbl(mincid, varid, "echo_number", 
                     general_info->acq.echo_number);
+    if (general_info->acq.echo_train_length != -DBL_MAX) /*add echo train length ilana*/
+        miattputdbl(mincid, varid, "echo_train_length", 
+                    general_info->acq.echo_train_length);
     if (general_info->acq.inv_time != -DBL_MAX)
         miattputdbl(mincid, varid, MIinversion_time, 
                     general_info->acq.inv_time);
@@ -843,9 +881,15 @@ void setup_minc_variables(int mincid, General_Info *general_info,
     if (general_info->acq.num_slices != -DBL_MAX)
         miattputdbl(mincid, varid, "num_slices", 
                     general_info->acq.num_slices);
+    if (strlen(general_info->acq.slice_order) > 0) /* add slice ordering info*/
+        miattputstr(mincid, varid, "slice_order", 
+                    general_info->acq.slice_order);
     if (general_info->acq.b_value != -DBL_MAX)
         miattputdbl(mincid, varid, "b_value", 
                     general_info->acq.b_value);
+    if (general_info->acq.delay_in_TR != -DBL_MAX) /*add delay in TR*/
+        miattputdbl(mincid, varid, "delay_in_TR", 
+                    general_info->acq.delay_in_TR);
 
     /* add number of dynamic scans (rhoge) */
     /* this will be relevant if we are receiving siemens scans that
@@ -901,13 +945,25 @@ void setup_minc_variables(int mincid, General_Info *general_info,
                     general_info->acq.image_type);
 
     if (strlen(general_info->acq.comments) > 0)
-        miattputstr(mincid, varid, MIcomments, 
+        miattputstr(mincid, varid, "image_comments", 
                     general_info->acq.comments);
 
     // this is Siemens Numaris 4 specific!
     if (strlen(general_info->acq.MrProt) > 0)
         miattputstr(mincid, varid, "MrProt_dump", 
                     general_info->acq.MrProt);
+    
+    /* Add DTI stuff if needed */
+    if (general_info->acq.dti) {
+        int length = general_info->cur_size[TIME];
+
+        double *tmp_ptr = calloc(length, sizeof(double));
+
+        ncattput(mincid, varid, "bvalues", NC_DOUBLE, length, tmp_ptr);
+        ncattput(mincid, varid, "direction_x", NC_DOUBLE, length, tmp_ptr);
+        ncattput(mincid, varid, "direction_y", NC_DOUBLE, length, tmp_ptr);
+        ncattput(mincid, varid, "direction_z", NC_DOUBLE, length, tmp_ptr);
+    }
 
     /* Create the dicom info variable */
     varid = ncvardef(mincid, "dicominfo", NC_LONG, 0, NULL);
@@ -922,22 +978,29 @@ void setup_minc_variables(int mincid, General_Info *general_info,
     miattputdbl(mincid, varid, "window_max", general_info->window_max);
 
     /* Put group info in header */
-    cur_group = general_info->group_list;
+    /* A lot of these dicom groups dump lots of junk into
+    the mincheader, and most of the information here has already
+    been included in the minc fields, we just should add those that
+    are missing and might be of use. Removing the fields starting with
+    "dicom_0x... for now   ilana*/
+    /*cur_group = general_info->group_list;
     dicomvar = ncvardef(mincid, DICOM_ROOT_VAR, NC_LONG, 0, NULL);
     miattputstr(mincid, dicomvar, MIvartype, MI_GROUP);
     miattputstr(mincid, dicomvar, MIvarid, "MNI DICOM variable");
-    miadd_child(mincid, ncvarid(mincid, MIrootvariable), dicomvar);
-    while (cur_group != NULL) {
+    miadd_child(mincid, ncvarid(mincid, MIrootvariable), dicomvar);*/
+
+    
+    /*while (cur_group != NULL) {*/
 
         /* Create variable for group */
-        sprintf(name, "dicom_0x%04x", acr_get_group_group(cur_group));
+        /*sprintf(name, "dicom_0x%04x", acr_get_group_group(cur_group));
         varid = ncvardef(mincid, name, NC_LONG, 0, NULL);
         miattputstr(mincid, varid, MIvartype, MI_GROUP);
         miattputstr(mincid, varid, MIvarid, "MNI DICOM variable");
-        miadd_child(mincid, dicomvar, varid);
+        miadd_child(mincid, dicomvar, varid);*/
 
         /* Loop through elements of group */
-        cur_element = acr_get_group_element_list(cur_group);
+        /*cur_element = acr_get_group_element_list(cur_group);
         while (cur_element != NULL) {
             sprintf(name, "el_0x%04x", 
                     acr_get_element_element(cur_element));
@@ -962,7 +1025,7 @@ void setup_minc_variables(int mincid, General_Info *general_info,
             cur_element = acr_get_element_next(cur_element);
         }
         cur_group = acr_get_group_next(cur_group);
-    }
+    }*/
 
     /* Create the history attribute */
     if (G.minc_history != NULL) {
@@ -972,6 +1035,21 @@ void setup_minc_variables(int mincid, General_Info *general_info,
     return;
 }
 
+/* Insert a scalar 'value' at 'position' along the given vector attribute
+ * of preallocated 'length'.
+ */
+void
+put_att_dbl(int mincid, int varid, char *attname, int length, int position,
+            double value)
+{
+    double *val_ptr = malloc(sizeof(double) * length);
+    if (val_ptr != NULL) {
+        ncattget(mincid, varid, attname, val_ptr);
+        val_ptr[position] = value;
+        ncattput(mincid, varid, attname, NC_DOUBLE, length, val_ptr);
+    }
+}
+            
 /* ----------------------------- MNI Header -----------------------------------
    @NAME       : save_minc_image
    @INPUT      : icvid
@@ -1048,6 +1126,36 @@ save_minc_image(int icvid, General_Info *gi_ptr,
                   &start[gi_ptr->image_index[TIME]], 
                   NC_DOUBLE, NULL, &fi_ptr->coordinate[TIME]);
 
+        if (gi_ptr->acq.dti) {
+            put_att_dbl(mincid, 
+                        ncvarid(mincid, MIacquisition),
+                        "bvalues", 
+                        gi_ptr->cur_size[TIME],
+                        start[gi_ptr->image_index[TIME]],
+                        fi_ptr->b_value);
+            
+            put_att_dbl(mincid, 
+                        ncvarid(mincid, MIacquisition),
+                        "direction_x", 
+                        gi_ptr->cur_size[TIME],
+                        start[gi_ptr->image_index[TIME]],
+                        fi_ptr->grad_direction[XCOORD]);
+                              
+            put_att_dbl(mincid, 
+                        ncvarid(mincid, MIacquisition),
+                        "direction_y", 
+                        gi_ptr->cur_size[TIME],
+                        start[gi_ptr->image_index[TIME]],
+                        fi_ptr->grad_direction[YCOORD]);
+                              
+            put_att_dbl(mincid, 
+                        ncvarid(mincid, MIacquisition),
+                        "direction_z",
+                        gi_ptr->cur_size[TIME],
+                        start[gi_ptr->image_index[TIME]],
+                        fi_ptr->grad_direction[ZCOORD]);
+        }
+
         /* If width information is present, save it to the appropriate
          * location in the time-width variable.
          */
