@@ -1,4 +1,4 @@
-#include <minc.h>
+#include <minc2.h>
 #include <ParseArgv.h>
 
 #include "nifti1_io.h"
@@ -109,7 +109,7 @@ init_nifti_header(nifti_image *nii_ptr)
     nii_ptr->iname = NULL;
     nii_ptr->iname_offset = 0;
     nii_ptr->swapsize = 0;
-    nii_ptr->byteorder = LSB_FIRST; /* Use LSB first by default. */
+    nii_ptr->byteorder = 1; /* default order (LSB) */
     nii_ptr->data = NULL;
 
     for (i = 0; i < 4; i++) {
@@ -120,6 +120,8 @@ init_nifti_header(nifti_image *nii_ptr)
             nii_ptr->sto_ijk.m[i][j] = 0.0;
         }
     }
+    
+    nii_ptr->num_ext = 0;
 }    
 
 /* private function from from libminc2.  This function is private partially
@@ -314,7 +316,7 @@ main(int argc, char **argv)
      */
     mnc_vid = ncvarid(mnc_fd, MIimage);
     if (mnc_vid < 0) {
-        fprintf(stderr, "Can't locate the image variable\n");
+        fprintf(stderr, "Can't locate the image variable (mnc_vid=%d)\n", mnc_vid);
         return (-1);
     }
 
@@ -362,8 +364,8 @@ main(int argc, char **argv)
         *str_ptr = '\0';
     }
 
-    nii_ptr->fname = malloc(strlen(out_str) + 4);
-    nii_ptr->iname = malloc(strlen(out_str) + 4);
+    nii_ptr->fname = malloc(strlen(out_str) + 4 + 1);
+    nii_ptr->iname = malloc(strlen(out_str) + 4 + 1);
     strcpy(nii_ptr->fname, out_str);
     strcpy(nii_ptr->iname, out_str);
 
@@ -454,6 +456,20 @@ main(int argc, char **argv)
         nii_ptr->pixdim[dimmap[i]] = (float) mnc_dstep;
     }
 
+    /* Here we do some "post-processing" of the results. Make certain that
+     * the nt value is never zero, and make certain that ndim is set to
+     * 4 if there is a time dimension and 5 if there is a vector dimension
+     */
+
+    if (nii_ptr->dim[3] > 1 && nii_ndims < 4) {
+        nii_ndims = 4;
+    }
+
+    if (nii_ptr->dim[4] > 1) {
+        nii_ptr->intent_code = NIFTI_INTENT_VECTOR;
+        nii_ndims = 5;
+    }
+
     nii_ptr->ndim = nii_ndims; /* Total number of dimensions in file */
     nii_ptr->nx = nii_ptr->dim[0];
     nii_ptr->ny = nii_ptr->dim[1];
@@ -522,16 +538,18 @@ main(int argc, char **argv)
 
         miattgetstr(mnc_fd, id, MIspacetype, sizeof(att_str), att_str);
 
-        /* Try to set the S-transform code correctly.  It is unclear that
-         * this is the right way to do it.
+        /* Try to set the S-transform code correctly.
          */
-        if (!strcmp(att_str, MI_NATIVE)) {
-            nii_ptr->sform_code = NIFTI_XFORM_SCANNER_ANAT;
-        }
         if (!strcmp(att_str, MI_TALAIRACH)) {
             nii_ptr->sform_code = NIFTI_XFORM_TALAIRACH;
         }
-        /* TODO: Anything for MI_CALLOSAL? */
+        else if (!strcmp(att_str, MI_CALLOSAL)) {
+            /* TODO: Not clear what do do here... */
+            nii_ptr->sform_code = NIFTI_XFORM_SCANNER_ANAT;
+        }
+        else {                  /* MI_NATIVE or unknown */
+            nii_ptr->sform_code = NIFTI_XFORM_SCANNER_ANAT;
+        }
     }
 
     /* So the last row is right... */
@@ -540,7 +558,7 @@ main(int argc, char **argv)
     nii_ptr->sto_xyz.m[3][2] = 0.0;
     nii_ptr->sto_xyz.m[3][3] = 1.0;
 
-    nii_ptr->sto_ijk = mat44_inverse(nii_ptr->sto_xyz);
+    nii_ptr->sto_ijk = nifti_mat44_inverse(nii_ptr->sto_xyz);
 
     nifti_datatype_sizes(nii_ptr->datatype, 
                          &nii_ptr->nbyper, &nii_ptr->swapsize);
@@ -620,6 +638,7 @@ main(int argc, char **argv)
         test_xform(nii_ptr->sto_xyz, 10, 10, 10);
     }
     
+    fprintf(stdout, "Calling NIFTI-1 Write routine\n");
     nifti_image_write(nii_ptr);
 
     return (0);
