@@ -14,6 +14,9 @@
                  miadd_child
                  micreate_std_variable
                  micreate_group_variable
+                 miget_version
+                 miappend_history
+                 micreate_ident
               private :
                  MI_create_dim_variable
                  MI_create_dimwidth_variable
@@ -27,8 +30,23 @@
 @CREATED    : July 27, 1992. (Peter Neelin, Montreal Neurological Institute)
 @MODIFIED   : 
  * $Log: minc_convenience.c,v $
- * Revision 6.12.2.1  2004/09/28 20:23:40  bert
- * Minor portability fixes for Windows
+ * Revision 6.18  2004/12/14 23:53:46  bert
+ * Get rid of compilation warnings
+ *
+ * Revision 6.17  2004/12/03 21:52:35  bert
+ * Minor changes for Windows build
+ *
+ * Revision 6.16  2004/10/15 13:46:15  bert
+ * Minor changes for Windows compatibility
+ *
+ * Revision 6.15  2004/08/26 16:14:21  bert
+ * Fix up miappend_history() again
+ *
+ * Revision 6.14  2004/06/04 18:15:46  bert
+ * Added micreate_ident()
+ *
+ * Revision 6.13  2004/04/27 15:49:17  bert
+ * Use new logging, gettext preparation
  *
  * Revision 6.12  2004/03/24 20:53:48  bert
  * Increase att_length by one in miappend_history() in order to read the entire attribute
@@ -119,13 +137,19 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/libsrc/minc_convenience.c,v 6.12.2.1 2004/09/28 20:23:40 bert Exp $ MINC (MNI)";
+static char rcsid[] = "$Header: /private-cvsroot/minc/libsrc/minc_convenience.c,v 6.18 2004/12/14 23:53:46 bert Exp $ MINC (MNI)";
 #endif
 
 #include "minc_private.h"
 #include "type_limits.h"
 #include "minc_varlists.h"
 
+#include <time.h>
+
+#if HAVE_UNISTD_H
+#include <unistd.h>             /* for getpid() */
+#endif /* HAVE_UNISTD_H */
+
 /* Private functions */
 PRIVATE int MI_create_dim_variable(int cdfid, char *name, 
                                    nc_type datatype, int ndims);
@@ -512,8 +536,8 @@ MNCAPI int miget_image_range(int cdfid, double image_range[])
 
          /* Get space */
          if ((buffer=MALLOC(size, double))==NULL) {
-            MI_LOG_SYS_ERROR1("miget_image_range");
-            MI_RETURN_ERROR(MI_ERROR);
+	     milog_message(MI_MSG_OUTOFMEM, size);
+	     MI_RETURN(MI_ERROR);
          }
 
          /* Get values */
@@ -521,7 +545,7 @@ MNCAPI int miget_image_range(int cdfid, double image_range[])
                       miset_coords(ndims, 0L, start),
                       count, NC_DOUBLE, NULL, buffer)==MI_ERROR) {
             FREE(buffer);
-            MI_RETURN_ERROR(MI_ERROR);
+            MI_RETURN(MI_ERROR);
          }
 
          /* Loop through values, getting max/min */
@@ -658,10 +682,8 @@ MNCAPI int miattget_pointer(int cdfid, int varid, char *name)
    /* Check for the prefix */
    for (index=0; prefix_string[index]!='\0'; index++) {
       if (pointer_string[index]!=prefix_string[index]) {
-         MI_LOG_PKG_ERROR3(MI_ERR_NOTPOINTER,
-                           "Attribute %s is not a pointer to a variable",
-                           name);
-         MI_RETURN_ERROR(MI_ERROR);
+	  milog_message(MI_MSG_ATTRNOTPTR, name);
+	  MI_RETURN(MI_ERROR);
       }
    }
 
@@ -711,8 +733,9 @@ MNCAPI int miadd_child(int cdfid, int parent_varid, int child_varid)
    /* Allocate space for new child list */
    if ((child_list = MALLOC(child_list_size+MAX_NC_NAME+
                             strlen(MI_CHILD_SEPARATOR), char)) == NULL) {
-      MI_LOG_SYS_ERROR1("miadd_child");
-      MI_RETURN_ERROR(MI_ERROR);
+       milog_message(MI_MSG_OUTOFMEM, 
+                     child_list_size+MAX_NC_NAME+strlen(MI_CHILD_SEPARATOR));
+       MI_RETURN(MI_ERROR);
    }
 
    /* Get the old list if needed and check for terminating null character 
@@ -721,7 +744,8 @@ MNCAPI int miadd_child(int cdfid, int parent_varid, int child_varid)
    if (child_list_size>0) {
       if (ncattget(cdfid, parent_varid, MIchildren, child_list) == MI_ERROR) {
          FREE(child_list);
-         MI_RETURN_ERROR(MI_ERROR);
+         milog_message(MI_MSG_READATTR, MIchildren);
+         MI_RETURN(MI_ERROR);
       }
       if (child_list[child_list_size-1] == '\0')
          child_list_size--;
@@ -827,18 +851,15 @@ MNCAPI int micreate_std_variable(int cdfid, char *name, nc_type datatype,
       else if (STRINGS_EQUAL(name, MIacquisition))
          MI_CHK_ERR(varid=MI_create_simple_variable(cdfid, name))
       else {
-         MI_LOG_PKG_ERROR3(MI_ERR_BAD_STDVAR, 
-                           "%s is not recognised as a standard MINC variable",
-                           name);
-         MI_RETURN_ERROR(MI_ERROR);
+	  milog_message(MI_MSG_VARNOTSTD, name);
+         MI_RETURN(MI_ERROR);
       }
    }
 
    /* If not in any list, then return an error */
    else {
-      MI_LOG_PKG_ERROR3(MI_ERR_BAD_STDVAR,
-                        "%s is not a standard MINC variable", name);
-      MI_RETURN_ERROR(MI_ERROR);
+       milog_message(MI_MSG_VARNOTSTD, name);
+       MI_RETURN(MI_ERROR);
    }
 
    MI_RETURN(varid);
@@ -872,16 +893,14 @@ PRIVATE int MI_create_dim_variable(int cdfid, char *name,
 
    /* Check for MIvector_dimension - no associated variable */
    if (STRINGS_EQUAL(name, MIvector_dimension)) {
-      MI_LOG_PKG_ERROR3(MI_ERR_BAD_STDVAR,
-                        "%s is not a standard MINC variable", name);
-      MI_RETURN_ERROR(MI_ERROR);
+       milog_message(MI_MSG_VARNOTSTD, name);
+       MI_RETURN(MI_ERROR);
    }
 
    /* Check for ndims being 0 or 1 */
    if (ndims>1) {
-      MI_LOG_PKG_ERROR2(MI_ERR_WRONGNDIMS,
-                        "Too many dimensions for a dimension variable");
-      MI_RETURN_ERROR(MI_ERROR);
+       milog_message(MI_MSG_TOOMANYDIMS, 1);
+       MI_RETURN(MI_ERROR);
    }
 
    /* Look for dimension and create the variable */
@@ -896,13 +915,13 @@ PRIVATE int MI_create_dim_variable(int cdfid, char *name,
    /* Add comments for spatial dimensions */ 
    if (STRINGS_EQUAL(name, MIxspace))
       {MI_CHK_ERR(miattputstr(cdfid, varid, MIcomments,
-                     "X increases from patient left to right"))}
+                              _("X increases from patient left to right")))}
    else if (STRINGS_EQUAL(name, MIyspace))
       {MI_CHK_ERR(miattputstr(cdfid, varid, MIcomments,
-                     "Y increases from patient posterior to anterior"))}
+                              _("Y increases from patient posterior to anterior")))}
    else if (STRINGS_EQUAL(name, MIzspace))
       {MI_CHK_ERR(miattputstr(cdfid, varid, MIcomments,
-                     "Z increases from patient inferior to superior"))}
+                              _("Z increases from patient inferior to superior")))}
 
    /* Dimension attributes */
    if (ndims==0) {
@@ -950,16 +969,15 @@ PRIVATE int MI_create_dimwidth_variable(int cdfid, char *name,
 
    /* Look for dimension name in name (remove width suffix) */
    if ((str=strstr(strcpy(string, name),MI_WIDTH_SUFFIX)) == NULL) {
-      MI_LOG_PKG_ERROR2(MI_ERR_BADSUFFIX,"Bad dimension width suffix");
-      MI_RETURN_ERROR(MI_ERROR);
+      milog_message(MI_MSG_DIMWIDTH);
+      MI_RETURN(MI_ERROR);
    }
    *str='\0';
 
    /* Check for ndims being 0 or 1 */
    if (ndims>1) {
-      MI_LOG_PKG_ERROR2(MI_ERR_WRONGNDIMS,
-                        "Too many dimensions for a dimension variable");
-      MI_RETURN_ERROR(MI_ERROR);
+      milog_message(MI_MSG_TOOMANYDIMS, 1);
+      MI_RETURN(MI_ERROR);
    }
 
    /* Look for the dimension */
@@ -1169,9 +1187,8 @@ PRIVATE int MI_verify_maxmin_dims(int cdfid,
    for (i=MAX(0,image_ndims-nbaddims); i<image_ndims; i++)
       for (j=0; j<maxmin_ndims; j++)
          if (image_dim[i]==maxmin_dim[j]) {
-            MI_LOG_PKG_ERROR2(MI_ERR_MAXMIN_DIMS,
-                        "Imagemax/min dimensions vary over image dimensions");
-            MI_RETURN_ERROR(MI_ERROR);
+             milog_message(MI_MSG_MAXMINVARY);
+	     MI_RETURN(MI_ERROR);
          }
 
    MI_RETURN(MI_NOERROR);
@@ -1332,49 +1349,52 @@ MNCAPI int
 miappend_history(int fd, const char *tm_stamp)
 {
     nc_type att_type;
-    int att_length;
+    int att_len;
     int r;
-    char *att_value;
+    char *att_val;
+    int old_ncopts;
 
-    r = ncattinq(fd, NC_GLOBAL, MIhistory, &att_type, &att_length);
+    old_ncopts = ncopts;
+    ncopts = 0;
+
+    r = ncattinq(fd, NC_GLOBAL, MIhistory, &att_type, &att_len);
     if (r < 0 || att_type != NC_CHAR) {
-        att_length = 0;
+        att_len = 0;
     }
 
-    /* For some reason, miattgetstr() needs to receive a value
-     * one larger than the value returned by ncattinq() in order
-     * to account for the terminating null character.
-     */
-    att_length++;
+    ncopts = old_ncopts;
 
     /* Allocate enough bytes for the existing attribute, the string which 
      * will be appended, a terminating null character, and a possible
      * additional newline.
      */
-    att_value = malloc(att_length + strlen(tm_stamp) + 1);
-    if (att_value == NULL) {
-        return (MI_ERROR);
-    }
-    if (miattgetstr(fd, NC_GLOBAL, MIhistory, att_length, att_value) == NULL) {
+    att_val = malloc(att_len + strlen(tm_stamp) + 2);
+    if (att_val == NULL) {
         return (MI_ERROR);
     }
 
-    if (att_value[att_length-1] == '\0') {
-        att_length--;
-    }
+    if (att_len != 0) {
+        if (miattgetstr(fd, NC_GLOBAL, MIhistory, att_len + 1, att_val) == NULL) {
+            return (MI_ERROR);
+        }
 
-    if (att_value[att_length-1] != '\n') {
-        att_value[att_length] = '\n';
-        att_length++;
+        while (att_val[att_len-1] == '\0' ) {
+            att_len--;
+        }
+
+        if (att_val[att_len-1] != '\n') {
+            att_val[att_len] = '\n';
+            att_len++;
+        }
     }
 
     /* Append the new history.
      */
-    strcpy(att_value + att_length, tm_stamp);
+    strcpy(att_val + att_len, tm_stamp);
 
-    r = miattputstr(fd, NC_GLOBAL, MIhistory, att_value);
+    r = miattputstr(fd, NC_GLOBAL, MIhistory, att_val);
 
-    free(att_value);
+    free(att_val);
 
     return (r);
 }
@@ -1420,7 +1440,69 @@ PRIVATE int MI_is_in_list(char *string, char *list[])
 @CREATED    : December 8 2003
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-const char * miget_version(void)
+MNCAPI const char * miget_version(void)
 {
     return (VERSION);
 }
+
+/* ----------------------------- MNI Header -----------------------------------
+@NAME       : micreate_ident
+@INPUT      : (none)
+@OUTPUT     : int
+@RETURNS    : The length of the ID string
+@DESCRIPTION: Creates a (hopefully) unique identifier to associate with a
+              MINC file, by concatenating various information about the
+              system, process, etc.
+              
+@METHOD     : 
+@GLOBALS    : 
+@CALLS      : 
+@CREATED    : 2004-May-11
+@MODIFIED   : 
+---------------------------------------------------------------------------- */
+#define MI_IDENT_SEP ':'
+
+MNCAPI int micreate_ident( char * id_str, size_t length )
+{
+    static int identx = 1;      /* Static ID counter */
+    time_t now;
+    struct tm tm_buf;
+    char host_str[128];
+    char user_str[128];
+    char *temp_ptr;
+    char time_str[26];
+    int result;
+
+    if (gethostname(host_str, sizeof(host_str)) != 0) {
+        strcpy(host_str, "unknown");
+    }
+
+    temp_ptr = getenv("LOGNAME");
+    if (temp_ptr != NULL) {
+        strcpy(user_str, temp_ptr);
+    }
+    else {
+        strcpy(user_str, "nobody");
+    }
+
+
+    time(&now);
+#ifdef _MSC_VER
+    memcpy(&tm_buf, localtime(&now), sizeof(tm_buf));
+#else
+    localtime_r(&now, &tm_buf);
+#endif
+    strftime(time_str, sizeof(time_str), "%Y.%m.%d.%H.%M.%S", &tm_buf);
+
+    result = snprintf(id_str, length, "%s%c%s%c%s%c%u%c%u", 
+                      user_str, 
+                      MI_IDENT_SEP,
+                      host_str, 
+                      MI_IDENT_SEP,
+                      time_str, 
+                      MI_IDENT_SEP,
+                      getpid(), 
+                      MI_IDENT_SEP,
+                      identx++);
+    return (result);
+}
