@@ -6,8 +6,8 @@
 @CREATED    : March 10, 1994 (Peter Neelin)
 @MODIFIED   : 
  * $Log: nd_loop.c,v $
- * Revision 6.1.2.1  2004/09/28 20:23:40  bert
- * Minor portability fixes for Windows
+ * Revision 6.2  2004/10/15 13:47:13  bert
+ * Minor changes for Windows compatibility
  *
  * Revision 6.1  2002/01/14 21:28:26  neelin
  * Moved nd_loop, voxel_loop, ParseArgv and time_stamp from ../progs/Proglib
@@ -50,7 +50,7 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/libsrc/nd_loop.c,v 6.1.2.1 2004/09/28 20:23:40 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/libsrc/nd_loop.c,v 6.2 2004/10/15 13:47:13 bert Exp $";
 #endif
 
 #include "minc_private.h"
