@@ -5,8 +5,8 @@
 @CREATED    : February 1, 1993 (Peter Neelin)
 @MODIFIED   : 
  * $Log: time_stamp.c,v $
- * Revision 6.1.2.1  2004/09/28 20:23:40  bert
- * Minor portability fixes for Windows
+ * Revision 6.2  2004/10/15 13:46:51  bert
+ * Minor changes for Windows compatibility
  *
  * Revision 6.1  2002/01/14 21:28:26  neelin
  * Moved nd_loop, voxel_loop, ParseArgv and time_stamp from ../progs/Proglib
@@ -56,7 +56,7 @@
 #include <time_stamp.h>
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/libsrc/time_stamp.c,v 6.1.2.1 2004/09/28 20:23:40 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/libsrc/time_stamp.c,v 6.2 2004/10/15 13:46:51 bert Exp $";
 #endif
 
 /* ----------------------------- MNI Header -----------------------------------
