@@ -10,6 +10,15 @@
 @CREATED    : June 13, 1994 (Peter Neelin)
 @MODIFIED   : 
  * $Log: voxeltoworld.c,v $
+ * Revision 6.7  2006/05/19 00:35:58  bert
+ * Add config.h to several files that might need it
+ *
+ * Revision 6.6  2004/11/01 22:38:38  bert
+ * Eliminate all references to minc_def.h
+ *
+ * Revision 6.5  2004/04/27 15:38:47  bert
+ * Added milog_init()
+ *
  * Revision 6.4  2004/02/02 18:27:51  bert
  * Call ParseArgv() so that version information can be output
  *
@@ -62,7 +71,11 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/coordinates/voxeltoworld.c,v 6.4 2004/02/02 18:27:51 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/progs/coordinates/voxeltoworld.c,v 6.7 2006/05/19 00:35:58 bert Exp $";
+#endif
+
+#if HAVE_CONFIG_H
+#include "config.h"
 #endif
 
 #include <stdlib.h>
@@ -70,7 +83,6 @@ static char rcsid[]="$Header: /private-cvsroot/minc/progs/coordinates/voxeltowor
 #include <string.h>
 #include <volume_io.h>
 #include <ParseArgv.h>
-#include <minc_def.h>
 
 /* Constants */
 #ifndef TRUE
@@ -105,6 +117,8 @@ int main(int argc, char *argv[])
    static char *dim_names[] =
       {ANY_SPATIAL_DIMENSION, ANY_SPATIAL_DIMENSION, ANY_SPATIAL_DIMENSION};
 
+   milog_init(argv[0]);
+
    /* Check arguments */
    if (ParseArgv(&argc, argv, argTable, 0) || argc != 5) {
       (void) fprintf(stderr, 
