@@ -10,8 +10,14 @@
 @CREATED    : March 31, 1995 (Peter Neelin)
 @MODIFIED   : 
  * $Log: minc_modify_header.c,v $
- * Revision 6.7.2.1  2005/03/16 19:02:49  bert
- * Port changes from 2.0 branch
+ * Revision 6.10  2004/11/01 22:38:38  bert
+ * Eliminate all references to minc_def.h
+ *
+ * Revision 6.9  2004/06/11 15:19:34  bert
+ * Fix attribute append operation
+ *
+ * Revision 6.8  2004/05/25 21:33:51  bert
+ * Add -dappend and -sappend
  *
  * Revision 6.7  2004/02/02 18:27:06  bert
  * Include config.h
@@ -72,7 +78,7 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/minc_modify_header/minc_modify_header.c,v 6.7.2.1 2005/03/16 19:02:49 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/progs/minc_modify_header/minc_modify_header.c,v 6.10 2004/11/01 22:38:38 bert Exp $";
 #endif
 
 #include "config.h"
