@@ -10,11 +10,17 @@
 @CREATED    : April 28, 1995 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincaverage.c,v $
- * Revision 6.4.2.2  2005/03/16 19:02:49  bert
- * Port changes from 2.0 branch
+ * Revision 6.8  2005/08/26 21:07:16  bert
+ * Use #if rather than #ifdef with MINC2 symbol, and be sure to include config.h whereever MINC2 is used
  *
- * Revision 6.4.2.1  2004/09/28 20:22:12  bert
- * Minor portability fix for Windows
+ * Revision 6.7  2004/12/14 23:52:50  bert
+ * Get rid of compilation warnings w/c99
+ *
+ * Revision 6.6  2004/11/01 22:38:38  bert
+ * Eliminate all references to minc_def.h
+ *
+ * Revision 6.5  2004/04/27 15:38:15  bert
+ * Added -2 option
  *
  * Revision 6.4  2001/04/24 13:38:42  neelin
  * Replaced NC_NAT with MI_ORIGINAL_TYPE.
@@ -71,9 +77,14 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincaverage/mincaverage.c,v 6.4.2.2 2005/03/16 19:02:49 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincaverage/mincaverage.c,v 6.8 2005/08/26 21:07:16 bert Exp $";
 #endif
 
+#if HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#define _GNU_SOURCE
 #include "config.h"
 #include <stdlib.h>
 #include <stdio.h>
@@ -171,9 +182,16 @@ double binvalue = -DBL_MAX;
 Double_Array weights = {0, NULL};
 int width_weighted = FALSE;
 char *filelist = NULL;
+#if MINC2
+int minc2_format = FALSE;
+#endif /* MINC2 */
 
 /* Argument table */
 ArgvInfo argTable[] = {
+#if MINC2
+    {"-2", ARGV_CONSTANT, (char *) TRUE, (char *) &minc2_format,
+     "Produce a MINC 2.0 format output file"},
+#endif /* MINC2 */
    {"-clobber", ARGV_CONSTANT, (char *) TRUE, (char *) &clobber,
        "Overwrite existing file."},
    {"-noclobber", ARGV_CONSTANT, (char *) FALSE, (char *) &clobber,
@@ -480,6 +498,9 @@ int main(int argc, char *argv[])
       vol_mean = malloc(sizeof(*vol_mean) * nfiles);
       loop_options = create_loop_options();
       set_loop_verbose(loop_options, FALSE);
+#if MINC2
+      set_loop_v2format(loop_options, minc2_format);
+#endif /* MINC2 */
       set_loop_accumulate(loop_options, TRUE, 0, NULL, NULL);
       set_loop_buffer_size(loop_options, (long) 1024 * max_buffer_size_in_kb);
       set_loop_check_dim_info(loop_options, check_dimensions);
