@@ -19,12 +19,21 @@ McGill University
 This is predominately a rehash of mincmath by Peter Neelin
 
  * $Log: minccalc.c,v $
- * Revision 1.8.2.2  2005/03/16 19:02:50  bert
- * Port changes from 2.0 branch
+ * Revision 1.13  2005/08/26 21:07:16  bert
+ * Use #if rather than #ifdef with MINC2 symbol, and be sure to include config.h whereever MINC2 is used
  *
- * Revision 1.8.2.1  2004/06/11 21:36:53  bert
+ * Revision 1.12  2004/12/14 23:52:23  bert
+ * Get rid of compilation warnings w/c99
+ *
+ * Revision 1.11  2004/11/01 22:38:38  bert
+ * Eliminate all references to minc_def.h
+ *
+ * Revision 1.10  2004/06/11 20:55:37  bert
  * Fix for nasty bug which causes lots of bogus zero values to be inserted when minccalc is used with a file with a vector_dimension
  *
+ * Revision 1.9  2004/04/27 15:37:52  bert
+ * Added -2 option
+ *
  * Revision 1.8  2001/05/24 15:08:40  neelin
  * Added support for comments so that minccalc scripts can be created.
  *
@@ -69,9 +78,14 @@ Mon May 21 01:01:01 EST 2000 - Original version "imgcalc" by David Leonard
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/minccalc/minccalc.c,v 1.8.2.2 2005/03/16 19:02:50 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/progs/minccalc/minccalc.c,v 1.13 2005/08/26 21:07:16 bert Exp $";
 #endif
 
+#if HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#define _GNU_SOURCE 1
 #include <stdlib.h>
 #include <stdio.h>
 #include <sys/types.h>
@@ -136,11 +150,18 @@ char     *filelist =                   NULL;
 char     *expr_file =                  NULL;
 char     *expression =                 NULL;
 int      eval_width =                  200;
+#if MINC2
+int      minc2_format =                FALSE;
+#endif /* MINC2 */
 
 /* Argument table */
 ArgvInfo argTable[] = {
    {NULL, ARGV_HELP, (char *) NULL, (char *) NULL, 
        "General options:"},
+#if MINC2
+    {"-2", ARGV_CONSTANT, (char *) TRUE, (char *) &minc2_format,
+     "Produce a MINC 2.0 format output file"},
+#endif /* MINC2 */
    {"-clobber", ARGV_CONSTANT, (char *) TRUE, (char *) &clobber,
        "Overwrite existing file."},
    {"-noclobber", ARGV_CONSTANT, (char *) FALSE, (char *) &clobber,
@@ -357,6 +378,9 @@ int main(int argc, char *argv[]){
    loop_options = create_loop_options();
    set_loop_verbose(loop_options, verbose);
    set_loop_clobber(loop_options, clobber);
+#if MINC2
+   set_loop_v2format(loop_options, minc2_format);
+#endif /* MINC2 */
    set_loop_datatype(loop_options, datatype, is_signed, 
                      valid_range[0], valid_range[1]);
    set_loop_copy_all_header(loop_options, copy_all_header);
