@@ -11,14 +11,20 @@
 @CREATED    : March 7, 1995 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincconcat.c,v $
- * Revision 6.8.2.3  2005/07/15 16:30:18  bert
- * Fix up filestarts option implementation
+ * Revision 6.13  2005/08/26 21:07:17  bert
+ * Use #if rather than #ifdef with MINC2 symbol, and be sure to include config.h whereever MINC2 is used
  *
- * Revision 6.8.2.2  2005/07/04 12:42:07  bert
- * Add -fileoffsets option
+ * Revision 6.12  2005/07/15 17:38:08  bert
+ * Add -filestarts option
  *
- * Revision 6.8.2.1  2005/03/16 19:02:50  bert
- * Port changes from 2.0 branch
+ * Revision 6.11  2004/12/14 23:52:08  bert
+ * Get rid of compilation warnings w/c99
+ *
+ * Revision 6.10  2004/11/01 22:38:38  bert
+ * Eliminate all references to minc_def.h
+ *
+ * Revision 6.9  2004/04/27 15:37:13  bert
+ * Added -2 flag
  *
  * Revision 6.8  2001/09/18 15:32:39  neelin
  * Create image variable last to allow big images and to fix compatibility
@@ -100,9 +106,14 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincconcat/mincconcat.c,v 6.8.2.3 2005/07/15 16:30:18 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincconcat/mincconcat.c,v 6.13 2005/08/26 21:07:17 bert Exp $";
 #endif
 
+#if HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#define _GNU_SOURCE 1
 #include <stdlib.h>
 #include <stdio.h>
 #include <float.h>
@@ -144,7 +155,7 @@ typedef struct {
    char *output_file;
    int num_input_files;
    char *history;
-   int clobber;
+   int cflags;
    int verbose;
    nc_type output_datatype;
    int output_is_signed;
@@ -296,6 +307,9 @@ static void get_arginfo(int argc, char *argv[],
 
    /* Argument variables */
    static int clobber = FALSE;
+#if MINC2
+   static int minc2_format = FALSE;
+#endif /* MINC2 */
    static int verbose = TRUE;
    static nc_type datatype = MI_ORIGINAL_TYPE;
    static int is_signed = INT_MIN;
@@ -315,6 +329,11 @@ static void get_arginfo(int argc, char *argv[],
    static ArgvInfo argTable[] = {
       {NULL, ARGV_HELP, (char *) NULL, (char *) NULL, 
           "General options:"},
+
+#if MINC2
+      {"-2", ARGV_CONSTANT, (char *) TRUE, (char *) &minc2_format,
+       "Produce a MINC 2.0 format output file"},
+#endif /* MINC2 */
       {"-clobber", ARGV_CONSTANT, (char *) TRUE, (char *) &clobber, 
           "Overwrite existing file."},
       {"-noclobber", ARGV_CONSTANT, (char *) FALSE, (char *) &clobber, 
@@ -509,7 +528,17 @@ static void get_arginfo(int argc, char *argv[],
    concat_info->output_file = output_file;
    concat_info->num_input_files = *num_input_files;
    concat_info->history = history;
-   concat_info->clobber = clobber;
+   if (clobber) {
+       concat_info->cflags = NC_CLOBBER;
+   }
+   else {
+       concat_info->cflags = NC_NOCLOBBER;
+   }
+#if MINC2
+   if (minc2_format) {
+       concat_info->cflags |= MI2_CREATE_V2;
+   }
+#endif /* MINC2 */
    concat_info->verbose = verbose;
    concat_info->max_memory_use_in_kb = max_chunk_size_in_kb;
    concat_info->check_dim_info = check_dim_info;
@@ -1206,8 +1235,7 @@ static void create_concat_file(int inmincid, Concat_Info *concat_info)
    double valid_range[2];
 
    /* Create the file */
-   outmincid = micreate(concat_info->output_file,
-                        (concat_info->clobber ? NC_CLOBBER : NC_NOCLOBBER));
+   outmincid = micreate(concat_info->output_file, concat_info->cflags);
 
    /* Get image variable id for input file */
    inimgid = ncvarid(inmincid, MIimage);
