@@ -10,8 +10,8 @@
 @CREATED    : August 24, 1993 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincexample1.c,v $
- * Revision 6.4.2.1  2005/03/16 19:02:50  bert
- * Port changes from 2.0 branch
+ * Revision 6.5  2004/11/01 22:38:38  bert
+ * Eliminate all references to minc_def.h
  *
  * Revision 6.4  2001/09/18 15:32:46  neelin
  * Create image variable last to allow big images and to fix compatibility
@@ -75,7 +75,7 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincexample/mincexample1.c,v 6.4.2.1 2005/03/16 19:02:50 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincexample/mincexample1.c,v 6.5 2004/11/01 22:38:38 bert Exp $";
 #endif
 
 #include <stdlib.h>
