@@ -10,8 +10,14 @@
 @CREATED    : January 20, 1995 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincexpand.c,v $
- * Revision 6.1.2.1  2005/03/16 19:02:50  bert
- * Port changes from 2.0 branch
+ * Revision 6.4  2006/05/19 00:35:58  bert
+ * Add config.h to several files that might need it
+ *
+ * Revision 6.3  2004/12/14 23:51:24  bert
+ * Get rid of compilation warning with c99
+ *
+ * Revision 6.2  2004/11/01 22:38:38  bert
+ * Eliminate all references to minc_def.h
  *
  * Revision 6.1  1999/10/19 14:45:22  neelin
  * Fixed Log subsitutions for CVS
@@ -53,9 +59,14 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincexpand/mincexpand.c,v 6.1.2.1 2005/03/16 19:02:50 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincexpand/mincexpand.c,v 6.4 2006/05/19 00:35:58 bert Exp $";
 #endif
 
+#if HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#define _GNU_SOURCE 1
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
