@@ -11,11 +11,17 @@
 @CREATED    : December 6, 1994 (Peter Neelin)
 @MODIFIED   : 
  * $Log: minclookup.c,v $
- * Revision 6.3.2.2  2005/03/16 19:02:51  bert
- * Port changes from 2.0 branch
+ * Revision 6.7  2005/08/26 21:07:17  bert
+ * Use #if rather than #ifdef with MINC2 symbol, and be sure to include config.h whereever MINC2 is used
  *
- * Revision 6.3.2.1  2004/09/28 20:08:14  bert
- * Minor portability fix for Windows
+ * Revision 6.6  2004/12/03 21:57:08  bert
+ * Include config.h
+ *
+ * Revision 6.5  2004/11/01 22:38:38  bert
+ * Eliminate all references to minc_def.h
+ *
+ * Revision 6.4  2004/05/20 21:52:08  bert
+ * Revised man pages
  *
  * Revision 6.3  2001/04/24 13:38:43  neelin
  * Replaced NC_NAT with MI_ORIGINAL_TYPE.
@@ -69,10 +75,12 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/minclookup/minclookup.c,v 6.3.2.2 2005/03/16 19:02:51 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/progs/minclookup/minclookup.c,v 6.7 2005/08/26 21:07:17 bert Exp $";
 #endif
 
+#if HAVE_CONFIG_H
 #include "config.h"
+#endif
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -207,9 +215,16 @@ double lookup_min = DEFAULT_RANGE;
 double lookup_max = DEFAULT_RANGE;
 int discrete_lookup = FALSE;
 char *null_value_string = NULL;
+#if MINC2
+int minc2_format = FALSE;
+#endif /* MINC2 */
 
 /* Argument table */
 ArgvInfo argTable[] = {
+#if MINC2
+    {"-2", ARGV_CONSTANT, (char *) TRUE, (char *) &minc2_format,
+     "Produce a MINC 2.0 format output file"},
+#endif /* MINC2 */
    {"-clobber", ARGV_CONSTANT, (char *) TRUE, (char *) &clobber,
        "Overwrite existing file."},
    {"-noclobber", ARGV_CONSTANT, (char *) FALSE, (char *) &clobber,
@@ -337,6 +352,9 @@ int main(int argc, char *argv[])
    loop_options = create_loop_options();
    set_loop_clobber(loop_options, clobber);
    set_loop_verbose(loop_options, verbose);
+#if MINC2
+   set_loop_v2format(loop_options, minc2_format);
+#endif /* MINC2 */
    set_loop_datatype(loop_options, datatype, is_signed, 
                      valid_range[0], valid_range[1]);
    set_loop_convert_input_to_scalar(loop_options, TRUE);
