@@ -10,11 +10,17 @@
 @CREATED    : August 7, 1997 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincmakescalar.c,v $
- * Revision 6.3.2.2  2005/03/16 19:02:51  bert
- * Port changes from 2.0 branch
+ * Revision 6.7  2005/08/26 21:07:17  bert
+ * Use #if rather than #ifdef with MINC2 symbol, and be sure to include config.h whereever MINC2 is used
  *
- * Revision 6.3.2.1  2005/01/25 21:01:52  bert
- * Check for proper placement of vector_dimension
+ * Revision 6.6  2005/01/28 19:34:09  bert
+ * Warn user if vector_dimension is not the last dimension in the image
+ *
+ * Revision 6.5  2004/11/01 22:38:38  bert
+ * Eliminate all references to minc_def.h
+ *
+ * Revision 6.4  2004/04/27 15:32:33  bert
+ * Added -2 option
  *
  * Revision 6.3  2001/04/24 13:38:43  neelin
  * Replaced NC_NAT with MI_ORIGINAL_TYPE.
@@ -43,7 +49,11 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincmakescalar/mincmakescalar.c,v 6.3.2.2 2005/03/16 19:02:51 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincmakescalar/mincmakescalar.c,v 6.7 2005/08/26 21:07:17 bert Exp $";
+#endif
+
+#if HAVE_CONFIG_H
+#include "config.h"
 #endif
 
 #include <stdlib.h>
@@ -95,6 +105,9 @@ static long get_vector_length(int mincid);
 
 /* Argument variables */
 int clobber = FALSE;
+#if MINC2
+int v2format = FALSE;
+#endif /* MINC2 */
 int verbose = TRUE;
 nc_type datatype = MI_ORIGINAL_TYPE;
 int is_signed = FALSE;
@@ -105,6 +118,10 @@ Double_Array linear_coefficients = {0, NULL};
 
 /* Argument table */
 ArgvInfo argTable[] = {
+#if MINC2
+    {"-2", ARGV_CONSTANT, (char *) TRUE, (char *) &v2format,
+       "Produce a MINC 2.0 format output file."},
+#endif /* MINC2 */
    {"-clobber", ARGV_CONSTANT, (char *) TRUE, (char *) &clobber,
        "Overwrite existing file."},
    {"-noclobber", ARGV_CONSTANT, (char *) FALSE, (char *) &clobber,
@@ -239,6 +256,9 @@ int main(int argc, char *argv[])
    loop_options = create_loop_options();
    set_loop_clobber(loop_options, clobber);
    set_loop_verbose(loop_options, verbose);
+#if MINC2
+   set_loop_v2format(loop_options, v2format);
+#endif /* MINC2 */
    set_loop_datatype(loop_options, datatype, is_signed, 
                      valid_range[0], valid_range[1]);
    set_loop_output_vector_size(loop_options, 1);
