@@ -11,14 +11,29 @@
 @CREATED    : February 8, 1993 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincresample.c,v $
- * Revision 6.12.2.3  2005/07/13 21:09:28  bert
- * Remove unused variables (port from 2.0 branch)
+ * Revision 6.20  2006/07/28 18:19:46  baghdadi
+ * *** empty log message ***
  *
- * Revision 6.12.2.2  2005/07/13 19:34:47  bert
- * Implemented sinc interpolant
+ * Revision 6.19  2006/07/28 17:54:57  baghdadi
+ * added vector dimension to list of excluded files (minc2.
  *
- * Revision 6.12.2.1  2005/03/16 19:02:51  bert
- * Port changes from 2.0 branch
+ * Revision 6.18  2005/08/26 21:07:17  bert
+ * Use #if rather than #ifdef with MINC2 symbol, and be sure to include config.h whereever MINC2 is used
+ *
+ * Revision 6.17  2005/07/13 21:34:24  bert
+ * Add sinc interpolant (ported from 1.X branch)
+ *
+ * Revision 6.16  2004/11/01 22:38:39  bert
+ * Eliminate all references to minc_def.h
+ *
+ * Revision 6.15  2004/04/30 19:53:40  bert
+ * Remove unused variable
+ *
+ * Revision 6.14  2004/04/30 18:52:49  bert
+ * Remove some unused variables
+ *
+ * Revision 6.13  2004/04/27 15:31:20  bert
+ * Added -2 option
  *
  * Revision 6.12  2003/09/18 15:01:33  bert
  * Removed unnecessary brackets from initializer
@@ -171,7 +186,11 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincresample/mincresample.c,v 6.12.2.3 2005/07/13 21:09:28 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincresample/mincresample.c,v 6.20 2006/07/28 18:19:46 baghdadi Exp $";
+#endif
+
+#if HAVE_CONFIG_H
+#include "config.h"
 #endif
 
 #include <stdlib.h>
@@ -270,10 +289,16 @@ static void get_arginfo(int argc, char *argv[],
           {NULL, NULL, NULL}, /* Pointers to coordinate arrays */
           {"", "", ""},       /* units */
           {"", "", ""}        /* spacetype */
-       }
+      },
+      FALSE			/* MINC 2.0 format? */
    };
 
    static ArgvInfo argTable[] = {
+#if MINC2
+       {"-2", ARGV_CONSTANT, (char *) TRUE, 
+	(char *) &args.v2format,
+       "Produce a MINC 2.0 format output file."},
+#endif /* MINC2 */
       {"-clobber", ARGV_CONSTANT, (char *) TRUE, 
           (char *) &args.clobber,
           "Overwrite existing file."},
@@ -447,6 +472,7 @@ static void get_arginfo(int argc, char *argv[],
    char *tm_stamp, *pname;
    Volume_Definition input_volume_def, transformed_volume_def;
    General_transform input_transformation;
+   int cflags;
 
    /* Initialize the transformation to identity */
    create_linear_transform(&input_transformation, NULL);
@@ -679,7 +705,18 @@ static void get_arginfo(int argc, char *argv[],
    out_vol->slice->data = malloc((size_t) total_size * sizeof(double));
 
    /* Create the output file */
-   create_output_file(outfile, args.clobber, &args.volume_def, 
+   if (args.clobber) {
+       cflags = NC_CLOBBER;
+   }
+   else {
+       cflags = NC_NOCLOBBER;
+   }
+#if MINC2
+   if (args.v2format) {
+       cflags |= MI2_CREATE_V2;
+   }
+#endif /* MINC2 */
+   create_output_file(outfile, cflags, &args.volume_def, 
                       in_vol->file, out_vol->file,
                       tm_stamp, &args.transform_info);
    
@@ -1159,8 +1196,7 @@ static void normalize_vector(double vector[])
 /* ----------------------------- MNI Header -----------------------------------
 @NAME       : create_output_file
 @INPUT      : filename - name of file to create
-              clobber - flag indicating whether any existing file should be
-                 overwritten
+              cflags - flag creation flags
               volume_def - description of volume
               in_file - description of input file
               out_file - description of output file
@@ -1176,7 +1212,7 @@ static void normalize_vector(double vector[])
 @CREATED    : February 9, 1993 (Peter Neelin)
 @MODIFIED   : 
 ---------------------------------------------------------------------------- */
-static void create_output_file(char *filename, int clobber, 
+static void create_output_file(char *filename, int cflags, 
                                Volume_Definition *volume_def,
                                File_Info *in_file,
                                File_Info *out_file,
@@ -1212,11 +1248,14 @@ static void create_output_file(char *filename, int clobber,
       excluded_vars[nexcluded++] = varid;
    if ((varid=ncvarid(in_file->mincid, MIimagemin)) != MI_ERROR)
       excluded_vars[nexcluded++] = varid;
+#if MINC2
+   if ((varid=ncvarid(in_file->mincid, MIvector_dimension)) != MI_ERROR)
+      excluded_vars[nexcluded++] = varid;
+#endif /* MINC2 */
    ncopts = NC_VERBOSE | NC_FATAL;
 
    /* Create the file */
-   out_file->mincid = micreate(filename, 
-                               (clobber ? NC_CLOBBER : NC_NOCLOBBER));
+   out_file->mincid = micreate(filename, cflags);
  
    /* Copy all other variable definitions */
    (void) micopy_all_var_defs(in_file->mincid, out_file->mincid, 
