@@ -6,8 +6,11 @@
 @CREATED    : October 25, 1994 (Peter Neelin)
 @MODIFIED   : 
  * $Log: copy_data.c,v $
- * Revision 6.3.2.1  2005/03/16 19:02:51  bert
- * Port changes from 2.0 branch
+ * Revision 6.5  2006/05/19 00:35:58  bert
+ * Add config.h to several files that might need it
+ *
+ * Revision 6.4  2004/11/01 22:38:39  bert
+ * Eliminate all references to minc_def.h
  *
  * Revision 6.3  2001/04/17 18:40:24  neelin
  * Modifications to work with NetCDF 3.x
@@ -66,7 +69,11 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincreshape/copy_data.c,v 6.3.2.1 2005/03/16 19:02:51 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincreshape/copy_data.c,v 6.5 2006/05/19 00:35:58 bert Exp $";
+#endif
+
+#if HAVE_CONFIG_H
+#include "config.h"
 #endif
 
 #include <stdlib.h>
