@@ -13,8 +13,14 @@
 @CREATED    : March 10, 1994 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincreshape.c,v $
- * Revision 6.8.2.1  2005/03/16 19:02:51  bert
- * Port changes from 2.0 branch
+ * Revision 6.11  2005/08/26 21:07:18  bert
+ * Use #if rather than #ifdef with MINC2 symbol, and be sure to include config.h whereever MINC2 is used
+ *
+ * Revision 6.10  2004/11/01 22:38:39  bert
+ * Eliminate all references to minc_def.h
+ *
+ * Revision 6.9  2004/04/27 15:30:02  bert
+ * Add -2 flag
  *
  * Revision 6.8  2001/11/13 14:16:50  neelin
  * Get correct valid range for conversion from int to float types
@@ -92,7 +98,11 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincreshape/mincreshape.c,v 6.8.2.1 2005/03/16 19:02:51 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincreshape/mincreshape.c,v 6.11 2005/08/26 21:07:18 bert Exp $";
+#endif
+
+#if HAVE_CONFIG_H
+#include "config.h"
 #endif
 
 #include <stdlib.h>
@@ -122,10 +132,8 @@ int main(int argc, char *argv[])
    /* Close the output file */
    (void) miattputstr(reshape_info.outmincid, reshape_info.outimgid,
                       MIcomplete, MI_TRUE);
-
    (void) miclose(reshape_info.outmincid);
    (void) miclose(reshape_info.inmincid);
-
    exit(EXIT_SUCCESS);
 }
 
@@ -172,6 +180,10 @@ static void get_arginfo(int argc, char *argv[],
    static long hs_count[MAX_VAR_DIMS] = {LONG_MIN};
    static double fillvalue = NOFILL;
    static int max_chunk_size_in_kb = DEFAULT_MAX_CHUNK_SIZE_IN_KB;
+#if MINC2
+   static int minc2_format = 0;
+#endif /* MINC2 */
+   int cflags;			/* File creation flags */
 
    /* Argument table */
    static ArgvInfo argTable[] = {
@@ -188,6 +200,10 @@ static void get_arginfo(int argc, char *argv[],
       {"-max_chunk_size_in_kb", ARGV_INT, (char *) 0, 
           (char *) &max_chunk_size_in_kb,
           "Specify the maximum size of the copy buffer (in kbytes)."},
+#if MINC2
+      {"-2", ARGV_CONSTANT, (char *) TRUE, (char *)&minc2_format,
+       "Produce a MINC 2.0 format output file."},
+#endif /* MINC2 */
 
       {NULL, ARGV_HELP, (char *) NULL, (char *) NULL, 
           "Image conversion options (pixel type and range):"},
@@ -430,8 +446,18 @@ static void get_arginfo(int argc, char *argv[],
                        ncvarid(reshape_info->inmincid, MIimage));
 
    /* Create the output file */
-   reshape_info->outmincid = 
-      micreate(outfile, (clobber ? NC_CLOBBER : NC_NOCLOBBER));
+   if (clobber) {
+       cflags = NC_CLOBBER;
+   }
+   else {
+       cflags = NC_NOCLOBBER;
+   }
+#if MINC2
+   if (minc2_format) {
+       cflags |= MI2_CREATE_V2;
+   }
+#endif /* MINC2 */
+   reshape_info->outmincid = micreate(outfile, cflags);
    setup_output_file(reshape_info->outmincid, history, reshape_info);
 
    return;
