@@ -5,20 +5,35 @@
  * University of Queensland, Australia
  *
  * $Log: mincstats.c,v $
- * Revision 1.14.2.5  2005/07/29 16:46:14  bert
+ * Revision 1.23  2007/09/27 01:06:31  rotor
+ *  * bugfix to histogram stats with a zero volume, discovered by Simon, fixed by
+ *       Claude
+ *
+ * Revision 1.22  2005/07/29 16:46:21  bert
  * Add warning message for mincstats -mask w/o -mask_range, -mask_binvalue, etc.
  *
- * Revision 1.14.2.4  2005/07/25 19:55:37  bert
+ * Revision 1.21  2005/07/25 19:56:52  bert
  * Fix pct_T calculation by taking into account a possibly non-zero histogram floor
  *
- * Revision 1.14.2.3  2005/03/16 19:02:52  bert
- * Port changes from 2.0 branch
+ * Revision 1.20  2005/05/20 15:39:45  bert
+ * Remove and/or conditionalize test code for memory-mapped files (see HDF5_MMAP_TEST)
  *
- * Revision 1.14.2.2  2004/10/18 15:02:13  bert
- * Ported AJanke's biModalT fix to 1.X branch
+ * Revision 1.19  2004/12/14 23:39:36  bert
+ * New bimodal threshold algorithms
  *
- * Revision 1.14.2.1  2004/09/28 20:03:40  bert
- * Minor portability changes for Windows
+ * Revision 1.18  2004/12/06 15:28:50  rotor
+ *  * Hopefully the final bug-fix for the BiModalT calculation
+ *
+ * Revision 1.17  2004/11/01 22:38:39  bert
+ * Eliminate all references to minc_def.h
+ *
+ * Revision 1.16  2004/10/18 08:20:35  rotor
+ *  * Changes to mincstats
+ *     - Fixed bug in calculation of BiModalT
+ *     - changed default # of histogram bins to 65536 (from 10000)
+ *
+ * Revision 1.15  2004/04/27 15:29:22  bert
+ * Added milog_init() call during initialization
  *
  * Revision 1.14  2003/09/05 18:29:40  bert
  * Avoid passing NULL to fprintf when no mask file is specified, to avoid seg. faults reported by Richard Boyes.
@@ -373,6 +388,7 @@ ArgvInfo argTable[] = {
    {NULL, ARGV_END, NULL, NULL, NULL}
 };
 
+
 /* Alternative thresholding algorithm.  This is more computationally
  * expensive than some of the alternatives, and doesn't seem to do a 
  * great job.  On the other hand it doesn't seem to fail like the 
@@ -738,6 +754,8 @@ int main(int argc, char *argv[])
    FILE    *FP;
    double   scale, voxmin, voxmax;
 
+   milog_init(argv[0]);
+
    /* Get arguments */
    if(ParseArgv(&argc, argv, argTable, 0) || (argc != 2)) {
       (void)fprintf(stderr, "\nUsage: %s [options] <infile.mnc>\n", argv[0]);
@@ -1025,7 +1043,7 @@ int main(int argc, char *argv[])
                /* BiModal Threshold */
                zero_moment += pdf[c];
                first_moment += hist_centre[c] * pdf[c];
-
+               
                if(c > 0 && zero_moment > 0.0 && zero_moment < 1.0) {
                   var = SQR((stats->mean * zero_moment) - first_moment) /
                      (zero_moment * (1 - zero_moment));
@@ -1355,7 +1373,8 @@ void do_stats(double value, long index[], Stats_Info * stats)
          }
       }
 
-      if(Hist && (value >= hist_range[0]) && (value <= hist_range[1])) {
+      if(Hist && (value >= hist_range[0]) && (value <= hist_range[1]) && 
+           (hist_sep > 0.0) ) {
          /*lower limit <= value < upper limit */
          hist_index = (int)floor((value - hist_range[0]) / hist_sep);
          if(hist_index >= hist_bins) {
