@@ -10,8 +10,14 @@
 @CREATED    : January 10, 1994 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincwindow.c,v $
- * Revision 6.1.2.1  2005/03/16 19:02:52  bert
- * Port changes from 2.0 branch
+ * Revision 6.4  2005/08/26 21:07:18  bert
+ * Use #if rather than #ifdef with MINC2 symbol, and be sure to include config.h whereever MINC2 is used
+ *
+ * Revision 6.3  2004/11/01 22:38:39  bert
+ * Eliminate all references to minc_def.h
+ *
+ * Revision 6.2  2004/04/27 15:28:39  bert
+ * Added -2 option
  *
  * Revision 6.1  1999/10/19 14:45:30  neelin
  * Fixed Log subsitutions for CVS
@@ -64,7 +70,11 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincwindow/mincwindow.c,v 6.1.2.1 2005/03/16 19:02:52 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincwindow/mincwindow.c,v 6.4 2005/08/26 21:07:18 bert Exp $";
+#endif
+
+#if HAVE_CONFIG_H
+#include "config.h"
 #endif
 
 #include <stdlib.h>
@@ -100,9 +110,16 @@ static void do_window(void *caller_data, long num_voxels,
 /* Argument variables */
 int clobber = FALSE;
 int verbose = TRUE;
+#if MINC2
+int v2format = FALSE;
+#endif /* MINC2 */
 
 /* Argument table */
 ArgvInfo argTable[] = {
+#if MINC2
+    {"-2", ARGV_CONSTANT, (char *) TRUE, (char *) &v2format,
+       "Produce a MINC 2.0 format output file."},
+#endif /* MINC2 */
    {"-clobber", ARGV_CONSTANT, (char *) TRUE, (char *) &clobber,
        "Overwrite existing file."},
    {"-noclobber", ARGV_CONSTANT, (char *) FALSE, (char *) &clobber,
@@ -165,6 +182,9 @@ int main(int argc, char *argv[])
    loop_options = create_loop_options();
    set_loop_verbose(loop_options, verbose);
    set_loop_clobber(loop_options, clobber);
+#if MINC2
+   set_loop_v2format(loop_options, v2format);
+#endif /* MINC2 */
    voxel_loop(1, &infile, 1, &outfile, arg_string, loop_options,
               do_window, (void *) &window_data);
 
