@@ -10,8 +10,8 @@
 @CREATED    : August 13, 1993 (Peter Neelin)
 @MODIFIED   : 
  * $Log: xfmconcat.c,v $
- * Revision 6.2.2.1  2005/03/16 19:02:52  bert
- * Port changes from 2.0 branch
+ * Revision 6.3  2004/11/01 22:38:39  bert
+ * Eliminate all references to minc_def.h
  *
  * Revision 6.2  2004/02/02 18:24:11  bert
  * Call ParseArgv() so that version information will be available
@@ -63,7 +63,7 @@
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/xfm/xfmconcat.c,v 6.2.2.1 2005/03/16 19:02:52 bert Exp $";
+static char rcsid[]="$Header: /private-cvsroot/minc/progs/xfm/xfmconcat.c,v 6.3 2004/11/01 22:38:39 bert Exp $";
 #endif
 
 #include <stdlib.h>
