@@ -16,7 +16,7 @@
 #include  <minc.h>
 
 #ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Volumes/input_mnc.c,v 1.65.2.2 2005/07/04 12:43:35 bert Exp $";
+static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Volumes/input_mnc.c,v 1.69 2007/09/13 01:31:38 rotor Exp $";
 #endif
 
 #define  INVALID_AXIS   -1
@@ -464,11 +464,14 @@ VIOAPI  Minc_file  initialize_minc_input_from_minc_id(
             set_volume_irregular_starts(volume, file->to_volume_index[d],
                                         file->sizes_in_file[d],
                                         irr_starts[d]);
+            FREE( irr_starts[d] );
         }
+        
         if (irr_widths[d] != NULL) {
             set_volume_irregular_widths(volume, file->to_volume_index[d],
                                         file->sizes_in_file[d],
                                         irr_widths[d]);
+            FREE( irr_widths[d] );
         }
     }
                                         
