@@ -17,7 +17,7 @@
 #include  <float.h>
 
 #ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Volumes/volumes.c,v 1.72.2.2 2005/07/04 12:43:36 bert Exp $";
+static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Volumes/volumes.c,v 1.77 2007/09/13 01:31:38 rotor Exp $";
 #endif
 
 STRING   XYZ_dimension_names[] = { MIxspace, MIyspace, MIzspace };
@@ -481,8 +481,11 @@ VIOAPI  void  delete_volume(
 
     delete_general_transform( &volume->voxel_to_world_transform );
 
-    for_less( d, 0, get_volume_n_dimensions(volume) )
+    for_less( d, 0, get_volume_n_dimensions(volume) ) {
         delete_string( volume->dimension_names[d] );
+        if( volume->irregular_starts[d] ) FREE( volume->irregular_starts[d] );
+        if( volume->irregular_widths[d] ) FREE( volume->irregular_widths[d] );
+    }
 
     delete_string( volume->coordinate_system_name );
 
@@ -2240,8 +2243,13 @@ VIOAPI  void  set_volume_real_range(
     if( get_volume_data_type(volume) == FLOAT ||
         get_volume_data_type(volume) == DOUBLE )
     {
+		/* as float and double use the voxel range */
+        volume->real_range_set = FALSE;
+
         set_volume_voxel_range( volume, real_min, real_max );
-        volume->real_value_scale = 1.0;
+        
+		/* these really shouldn't be needed but let's be "safe" */
+		volume->real_value_scale = 1.0;
         volume->real_value_translation = 0.0;
     }
     else
@@ -2336,7 +2344,7 @@ VIOAPI  Volume   copy_volume_definition_no_alloc(
     }
 
     set_volume_space_type( copy, volume->coordinate_system_name );
-
+    
     for_less( c, 0, get_volume_n_dimensions(volume) )
     {
         if (is_volume_dimension_irregular(volume, c)) {
@@ -2345,8 +2353,10 @@ VIOAPI  Volume   copy_volume_definition_no_alloc(
             get_volume_irregular_starts( volume, c, sizes[c], irr_starts);
             set_volume_irregular_starts( volume, c, sizes[c], irr_starts);
 
-            get_volume_irregular_widths( volume, c, sizes[c], irr_starts);
-            set_volume_irregular_widths( volume, c, sizes[c], irr_starts);
+            get_volume_irregular_widths( volume, c, sizes[c], irr_widths);
+            set_volume_irregular_widths( volume, c, sizes[c], irr_widths);
+            free( irr_starts );
+            free( irr_widths );
         }
     }
 
